==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/hal/translations/hal_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="31"/>
        <source>HAL Plugin</source>
        <translation>Wtyczka HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>About HAL Plugin</source>
        <translation>O wtyczce HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Wtyczka HAL dla Qmmp</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Ta wtyczka umożliwia detekcję urządzeń przenośnych dzięki HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="55"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Oparte na Solid (biblioteka urządzeń dla KDE)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="160"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Dodaj CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="166"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Dodaj urządzenie &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>Ustawienia wtyczki HAL</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Detekcja płyt CD Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Automatycznie dodaj utwory do listy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Automatycznie usuń utwory z listy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Detekcja urządzeń przenośnych</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Automatycznie dodaj pliki do listy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Automatycznie usuń pliki z listy</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.3.orig.tar.bz2: qmmp-1.4.3/src/plugins/General/hal/translations/hal_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>HalFactory</name>
    <message>
        <location filename="../halfactory.cpp" line="30"/>
        <source>HAL Plugin</source>
        <translation>Wtyczka HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="50"/>
        <source>About HAL Plugin</source>
        <translation>O wtyczce HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="51"/>
        <source>Qmmp HAL Plugin</source>
        <translation>Wtyczka HAL dla Qmmp</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using HAL</source>
        <translation>Ta wtyczka umożliwia detekcję urządzeń przenośnych dzięki HAL</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Napisana przez: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../halfactory.cpp" line="54"/>
        <source>Based on Solid (KDE hardware library)</source>
        <translation>Oparta na Solid (biblioteka urządzeń dla KDE)</translation>
    </message>
</context>
<context>
    <name>HalPlugin</name>
    <message>
        <location filename="../halplugin.cpp" line="165"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Dodaj CD &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../halplugin.cpp" line="171"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Dodaj urządzenie &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>HAL Plugin Settings</source>
        <translation>Ustawienia wtyczki HAL</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="28"/>
        <source>CD Audio Detection</source>
        <translation>Detekcja płyt CD Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="37"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Automatycznie dodaj utwory do listy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Automatycznie usuń utwory z listy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>Removable Device Detection</source>
        <translation>Detekcja urządzeń przenośnych</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Add files to playlist automatically</source>
        <translation>Automatycznie dodaj pliki do listy</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="70"/>
        <source>Remove files from playlist automatically</source>
        <translation>Automatycznie usuń pliki z listy</translation>
    </message>
</context>
</TS>
